@@ -9,6 +9,7 @@ import nanotime
 from dvc.exceptions import DvcException
 from dvc.system import System
 from dvc.utils import dict_md5
+from dvc.utils import fspath
 from dvc.utils import fspath_py35
 from dvc.utils import walk_files
 from dvc.utils.compat import str
@@ -61,6 +62,9 @@ class BasePathNotInCheckedPathException(DvcException):
 
 
 def contains_symlink_up_to(path, base_path):
+    base_path = fspath(base_path)
+    path = fspath(path)
+
     if base_path not in path:
         raise BasePathNotInCheckedPathException(path, base_path)
 
@@ -71,22 +75,3 @@ def contains_symlink_up_to(path, base_path):
     if os.path.dirname(path) == path:
         return False
     return contains_symlink_up_to(os.path.dirname(path), base_path)
-
-
-def get_parent_dirs_up_to(wdir, root_dir):
-
-    assert os.path.isabs(wdir)
-    assert os.path.isabs(root_dir)
-
-    wdir = os.path.normpath(wdir)
-    root_dir = os.path.normpath(root_dir)
-    if root_dir not in wdir:
-        return []
-
-    dirs = []
-    dirs.append(wdir)
-    while wdir != root_dir:
-        wdir = os.path.dirname(wdir)
-        dirs.append(wdir)
-
-    return dirs
